The SEDs listed in COSMOS_seds.list are a set of 31 template SEDs that were used to compute the COSMOS 30-band photo-z's using LePhare.  The template set consists of empirical templates from [Poletta et al 2007](https://arxiv.org/pdf/astro-ph/0703255) supplemented with blue [BC03](https://ui.adsabs.harvard.edu/abs/2003MNRAS.344.1000B/abstract) SEDs, see [Ilbert et al 2009](https://ui.adsabs.harvard.edu/abs/2009ApJ...690.1236I/abstract) and [Dahlen et al 2013](https://ui.adsabs.harvard.edu/abs/2013ApJ...775...93D/abstract) for details.